==> kubernetes-model-1.0.29-sources.jar: io/fabric8/kubernetes/api/model/LoadBalancerStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;

public class LoadBalancerStatusFluentImpl<T extends LoadBalancerStatusFluent<T>> extends BaseFluent<T> implements LoadBalancerStatusFluent<T>{

     List<VisitableBuilder<LoadBalancerIngress, ?>> ingress = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();

    public T addToIngress( LoadBalancerIngress ...items){
    for (LoadBalancerIngress item : items) {LoadBalancerIngressBuilder builder = new LoadBalancerIngressBuilder(item);_visitables.add(builder);this.ingress.add(builder);} return (T)this;
    }
    public T removeFromIngress( LoadBalancerIngress ...items){
    for (LoadBalancerIngress item : items) {LoadBalancerIngressBuilder builder = new LoadBalancerIngressBuilder(item);_visitables.remove(builder);this.ingress.remove(builder);} return (T)this;
    }
    public List<LoadBalancerIngress> getIngress(){
    return build(ingress);
    }
    public T withIngress( List<LoadBalancerIngress> ingress){
    this.ingress.clear();if (ingress != null) {for (LoadBalancerIngress item : ingress){this.addToIngress(item);}} return (T) this;
    }
    public T withIngress( LoadBalancerIngress ...ingress){
    this.ingress.clear(); if (ingress != null) {for (LoadBalancerIngress item :ingress){ this.addToIngress(item);}} return (T) this;
    }
    public IngressNested<T> addNewIngres(){
    return new IngressNestedImpl<T>();
    }
    public IngressNested<T> addNewIngresLike( LoadBalancerIngress item){
    return new IngressNestedImpl<T>(item);
    }
    public T addNewIngres( String hostname,  String ip){
    return addToIngress(new LoadBalancerIngress(hostname, ip));
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
LoadBalancerStatusFluentImpl that = (LoadBalancerStatusFluentImpl) o;
if (ingress != null ? !ingress.equals(that.ingress) :that.ingress != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class IngressNestedImpl<N> extends LoadBalancerIngressFluentImpl<IngressNested<N>> implements IngressNested<N>{

        private final LoadBalancerIngressBuilder builder;
    
             IngressNestedImpl (){
        this.builder = new LoadBalancerIngressBuilder(this);
        }
             IngressNestedImpl ( LoadBalancerIngress item){
        this.builder = new LoadBalancerIngressBuilder(this, item);
        }
    
            public N and(){
            return (N) LoadBalancerStatusFluentImpl.this.addToIngress(builder.build());
        }
            public N endIngres(){
            return and();
        }
    
}


}

==> kubernetes-model-1.0.38-sources.jar: io/fabric8/kubernetes/api/model/LoadBalancerStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;

public class LoadBalancerStatusFluentImpl<T extends LoadBalancerStatusFluent<T>> extends BaseFluent<T> implements LoadBalancerStatusFluent<T>{

     List<VisitableBuilder<LoadBalancerIngress, ?>> ingress = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();
public LoadBalancerStatusFluentImpl(){
    
}
public LoadBalancerStatusFluentImpl( LoadBalancerStatus instance ){
    this.withIngress(instance.getIngress()); 
}

    public T addToIngress( LoadBalancerIngress ...items){
    for (LoadBalancerIngress item : items) {LoadBalancerIngressBuilder builder = new LoadBalancerIngressBuilder(item);_visitables.add(builder);this.ingress.add(builder);} return (T)this;
    }
    public T removeFromIngress( LoadBalancerIngress ...items){
    for (LoadBalancerIngress item : items) {LoadBalancerIngressBuilder builder = new LoadBalancerIngressBuilder(item);_visitables.remove(builder);this.ingress.remove(builder);} return (T)this;
    }
    public List<LoadBalancerIngress> getIngress(){
    return build(ingress);
    }
    public T withIngress( List<LoadBalancerIngress> ingress){
    this.ingress.clear();if (ingress != null) {for (LoadBalancerIngress item : ingress){this.addToIngress(item);}} return (T) this;
    }
    public T withIngress( LoadBalancerIngress ...ingress){
    this.ingress.clear(); if (ingress != null) {for (LoadBalancerIngress item :ingress){ this.addToIngress(item);}} return (T) this;
    }
    public IngressNested<T> addNewIngres(){
    return new IngressNestedImpl<T>();
    }
    public IngressNested<T> addNewIngresLike( LoadBalancerIngress item){
    return new IngressNestedImpl<T>(item);
    }
    public T addNewIngres( String hostname,  String ip){
    return addToIngress(new LoadBalancerIngress(hostname, ip));
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
LoadBalancerStatusFluentImpl that = (LoadBalancerStatusFluentImpl) o;
if (ingress != null ? !ingress.equals(that.ingress) :that.ingress != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class IngressNestedImpl<N> extends LoadBalancerIngressFluentImpl<IngressNested<N>> implements IngressNested<N>{

        private final LoadBalancerIngressBuilder builder;
    
             IngressNestedImpl ( LoadBalancerIngress item){
        this.builder = new LoadBalancerIngressBuilder(this, item);
        }
             IngressNestedImpl (){
        this.builder = new LoadBalancerIngressBuilder(this);
        }
    
            public N and(){
            return (N) LoadBalancerStatusFluentImpl.this.addToIngress(builder.build());
        }
            public N endIngres(){
            return and();
        }
    
}


}
